/*
 * Tlf - contest logging program for amateur radio operators
 * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef PACCDX_H
#define PACCDX_H

#define W_CALL 0
#define VE_CALL 1
#define ZL_CALL 2
#define JA_CALL 3
#define PY_CALL 4
#define CE_CALL 5
#define LU_CALL 6
#define VK_CALL 7
#define ZS_CALL 8
#define UA9_CALL 9

int pacc_pa(void);

#endif /* PACCDX_H */
